/*
 * Copyright (c) 2020 Arm Limited. All rights reserved.
 *
 * This Software is licensed under an Arm proprietary license.
 *
 * -----------------------------------------------------------------------------
 *
 * Project:     CMSIS-RTOS RTX
 * Title:       SVC User Table
 *
 * -----------------------------------------------------------------------------
 */
#include <stdint.h>
#include "RTE_Components.h"               /* Component selection */
#include CMSIS_device_header


void EnablePrivelegedMode(void);
void EnablePrivelegedMode(void){
__set_CONTROL( __get_CONTROL( ) & ~CONTROL_nPRIV_Msk ) ;
}
	
extern void svc_EnablePrivelegedMode(void);
__attribute__((always_inline)) void svc_EnablePrivelegedMode (void) {    \
	  __asm volatile("SVC #1" : :);	
}

void DisablePrivelegedMode(void);
void DisablePrivelegedMode(void){
__set_CONTROL( __get_CONTROL( ) | CONTROL_nPRIV_Msk ) ;
}

extern void svc_DisablePrivelegedMode(void);
__attribute__((always_inline)) void svc_DisablePrivelegedMode (void) {    \
	  __asm volatile("SVC #2" : :);
}


extern void StlCpuTMTest(uint32_t testNumber);
extern void svc_StlCpuTMTest(uint32_t testNumber);
__attribute__((always_inline)) void svc_StlCpuTMTest (uint32_t testNumber) {    
	register unsigned r0 __asm("r0") = testNumber; 
	__asm volatile("SVC #3" : : "r" (r0));
}

extern void StlFlashTestRun(uint32_t startAddr, uint32_t endAddr, uint32_t sections);
extern void svc_StlFlashTest(uint32_t startAddr, uint32_t endAddr, uint32_t sections);
__attribute__((always_inline)) void svc_StlFlashTest(uint32_t startAddr, uint32_t endAddr, uint32_t sections) {    \
	  register unsigned r0 __asm("r0") = startAddr; 
	  register unsigned r1 __asm("r1") = endAddr; 
	  register unsigned r2 __asm("r2") = sections;
	  __asm volatile(
			"SVC #4"
		  :
	    : "r" (r0), "r" (r1),"r" (r2)	
		);
}

extern void StlRamTestRun(uint32_t startAddr, uint32_t endAddr, uint32_t sections);
extern void svc_StlRamTest(uint32_t startAddr, uint32_t endAddr, uint32_t sections);
__attribute__((always_inline)) void svc_StlRamTest (uint32_t startAddr, uint32_t endAddr, uint32_t sections) {    \
		register unsigned r0 __asm("r0") = startAddr; 
	  register unsigned r1 __asm("r1") = endAddr; 
	  register unsigned r2 __asm("r2") = sections;
	  __asm volatile(
			"SVC #5"
		  :
	    : "r" (r0), "r" (r1),"r" (r2)	
		);
}

#define USER_SVC_COUNT  5     // Number of user SVC functions

extern void * const osRtxUserSVC[1+USER_SVC_COUNT];
       void * const osRtxUserSVC[1+USER_SVC_COUNT] = {
  (void *)USER_SVC_COUNT,
	(void *)EnablePrivelegedMode,
	(void *)DisablePrivelegedMode,		
  (void *)StlCpuTMTest,
  (void *)StlFlashTestRun,		
	(void *)StlRamTestRun,		
// ...
};
